<?php
 
function new_shop_frontend_form_register() {	

//for shop basic
	$cmb_post = new_cmb2_box( array(
		'id'           => 'front-end-shop-form',
		'object_types' => array( 'shop' ),
		'hookup'       => false,
		'cmb_styles' => false,		
		'save_fields'  => false,
	) );
	
	$cmb_post->add_field( array( // 标题模块
		'name'    => __( '店铺名称', 'chumi' ),
		'id'      => 'submitted_post_title',
		'type'    => 'text',		
		'show_names' => false,
		'attributes' => array(
			'autocomplete' => 'off', 
			'class'=>'required',
			'placeholder'=>'输入店铺标题',
		),
	) ); 

	$cmb_post->add_field( array( // 内容模块
		'name'    => __( '店铺介绍', 'chumi' ),
		'id'      => 'submitted_post_content',
		'type'    => 'wysiwyg', 
		'attributes' => array(
			'class'=>'required',
		),		
		'options' => array(
			'media_buttons' => false, 
			'teeny' => true,
			'tinymce' => true, 
			'class'=>'required',
			'textarea_rows' => 25, 
			'quicktags' => false 
		),
	) );		
	$cmb_post->add_field( array( //当前最多可选5个
		'name'    => __( '服务类别', 'cmb2' ),
		'id'      => 'submitted_post_cat',
		'type'    => 'terms_rdo_inline', //该函数定义在最前面
	) );
	
	$cmb_post->add_field( array( 
		'id'      => 'page_script_fake',
		'type'    => 'post_script', 
	) ); 	
				
}

add_action( 'cmb2_init', 'new_shop_frontend_form_register' );

function shop_frontend_cmb2_get() {
	$metabox_id = 'front-end-shop-form';
	$object_id  = 'fake-object-id';	
	return cmb2_get_metabox( $metabox_id, $object_id );
}

function shop_frontend_form_submission_shortcode( $atts = array() ) {
	
 	if ( ! current_user_can( 'edit_posts' ) ) {
		return __( '对不起！您没有权限浏览该页面 >_< ', '' );
	} 
	
	$cmb = shop_frontend_cmb2_get();
	$post_types = $cmb->prop( 'object_types' );
	$user_id = get_current_user_id();

	$atts = shortcode_atts( array(
		'post_author' => $user_id ? $user_id : 1, // Current user, or admin
		'post_status' => 'pending',
		'post_type'   => reset( $post_types ), // Only use first object_type in array
	), $atts, 'cmb-shop-frontend-form' );

	foreach ( $atts as $key => $value ) {
		$cmb->add_hidden_field( array(
			'field_args'  => array(
				'id'    => 'atts[$key]',
				'type'  => 'hidden',
				'default' => $value,
			),
		) );
	}

	$output = '';

	if ( ( $error = $cmb->prop( 'submission_error' ) ) && is_wp_error( $error ) ) {
		$output .= '<span class="app-tips app-tips-error">' . sprintf( __( '提交出错: %s', '' ), '<strong>'. $error->get_error_message() .'</strong>' ) . '</span>';
	}
	$output .= cmb2_get_metabox_form( $cmb,'fake-object-id', array( 'save_button' => __( '完成提交', 'chumi' ) ) );

	return $output;
}
add_shortcode( 'cmb-shop-frontend-form', 'shop_frontend_form_submission_shortcode' );

function chumi_handle_frontend_new_shop_form_submission() {

	if ( empty( $_POST ) || ! isset( $_POST['submit-cmb'], $_POST['object_id'] ) ) {
		return false;
	}

	$cmb = shop_frontend_cmb2_get();

	$post_data = array();

	if ( isset( $_POST['atts'] ) ) {
		foreach ( (array) $_POST['atts'] as $key => $value ) {
			$post_data[ $key ] = sanitize_text_field( $value );
		}
		//unset( $_POST['atts'] );
	}

	if ( ! isset( $_POST[ $cmb->nonce() ] ) || ! wp_verify_nonce( $_POST[ $cmb->nonce() ], $cmb->nonce() ) ) {
		return $cmb->prop( 'submission_error', new WP_Error( 'security_fail', __( '未能通过安全检查！' ) ) );
	}

	if ( empty( $_POST['submitted_post_title'] ) ) {
		return $cmb->prop( 'submission_error', new WP_Error( 'post_data_missing', __( '请在标题框中输入标题！' ) ) );
	}

	if ( empty( $_POST['submitted_post_content'] ) ) {
		return $cmb->prop( 'submission_error', new WP_Error( 'post_data_missing', __( '请填写文章内容后再提交' ) ) );
	}

	if ( $cmb->get_field( 'submitted_post_title' )->default() == $_POST['submitted_post_title'] ) {
		return $cmb->prop( 'submission_error', new WP_Error( 'post_data_missing', __( '重复！请输入一个新标题。' ) ) );
	}		

	$sanitized_values = $cmb->get_sanitized_values( $_POST );

	// Set our post data arguments
	$post_data['post_title']   = $sanitized_values['submitted_post_title'];
	unset( $sanitized_values['submitted_post_title'] );
	$post_data['post_content'] = $sanitized_values['submitted_post_content'];
	unset( $sanitized_values['submitted_post_content'] );
	$post_data['tags_input'] = $sanitized_values['submitted_post_tag'];
	unset( $sanitized_values['submitted_post_tag'] );
	
	$cat = $sanitized_values['submitted_post_cat'];
	
	if(empty($cat)) { $cat = 1;	}
	
	$category = get_term_by( 'id',$cat,'category')->name;
	unset( $sanitized_values['submitted_post_cat'] );	

	// Create the new post
	$new_submission_id = wp_insert_post( $post_data, true );	
	wp_set_object_terms( $new_submission_id, $category, 'category');
	$title = mb_strimwidth(strip_tags(Pinyin::getPinyin($post_data['post_title'])), 0, 60,"");
	$name = substr(md5($title), 0, 15);
	wp_update_post( array( 'ID' => $new_submission_id,'post_name'  => $name.'_'.$new_submission_id) );

	// If we hit a snag, update the user
	if ( is_wp_error( $new_submission_id ) ) {
		return $cmb->prop( 'submission_error', $new_submission_id );
	}

	unset( $post_data['post_type'] );
	unset( $post_data['post_status'] );

	foreach ( $sanitized_values as $key => $value ) {
		if ( is_array( $value ) ) {
			$value = array_filter( $value );
			if( ! empty( $value ) ) {
				update_post_meta( $new_submission_id, $key, $value );
			}
		} else {
			update_post_meta( $new_submission_id, $key, $value );
		}
	}
	
	wp_redirect(home_url(). '/?p='.$new_submission_id);	
	
	exit;	

}
add_action( 'cmb2_after_init', 'chumi_handle_frontend_new_shop_form_submission' );

/*
*Edit FORM
*/
function edit_shop_frontend_form_register() {

//for shop header

	$cmb_post = new_cmb2_box( array(
		'id'           => 'front-end-shopHeader-form',
		'object_types' => array( 'shop' ),
		'hookup'       => false,
		'cmb_styles' => false,		
		'save_fields'  => false,
	) );
	
	$cmb_post->add_field( array( // 标题模块
		'name'    => __( '页头背景颜色', 'chumi' ),
		'id'      => 'shop_header_color',
		'type'    => 'colorpicker',
		'default' => '#ffffff',
	) ); 

	$cmb_post->add_field( array( // 内容模块
		'name'    => __( '页头背景图片', 'chumi' ),
		'id'      => 'shop_header_image',
		'type'    => 'file', 
	) );

	$cmb_post->add_field( array( // 内容模块
		'name'    => __( '店铺LOGO', 'chumi' ),
		'id'      => 'shop_header_image',
		'type'    => 'file', 
	) );

	$cmb_post->add_field( array( // 内容模块
		'name'    => __( '主页背景颜色', 'chumi' ),
		'id'      => 'shop_page_color',
		'type'    => 'colorpicker',
		'default' => '#ffffff',
	) );
	
	$cmb_post->add_field( array( // 内容模块
		'name'    => __( '主页背景图片', 'chumi' ),
		'id'      => 'shop_page_image',
		'type'    => 'file', 
	) );
	
	$cmb_post->add_field( array( // 内容模块
		'name'    => __( '导航菜单', 'chumi' ),
		'id'      => 'shop_nav',
		'type'    => 'group', 
	) );	
	
	$cmb_post->add_field( array( 
		'id'      => 'page_script_fake',
		'type'    => 'post_script', 
	) ); 
	
}
add_action( 'cmb2_init', 'edit_shop_frontend_form_register' );

function shopHeader_frontend_cmb2_get() {
	$metabox_id = 'front-end-shopHeader-form';
	$object_id  = 'fake-object-id';		
	return cmb2_get_metabox( $metabox_id, $object_id );
}

function shopHeader_frontend_form_submission_shortcode( $atts = array() ) {
	
 	if ( ! current_user_can( 'edit_posts' ) ) {
		return __( '对不起！您没有权限浏览该页面 >_< ', '' );
	} 
	
	$cmb = shopHeader_frontend_cmb2_get();
	$post_types = $cmb->prop( 'object_types' );
	$user_id = get_current_user_id();

	$atts = shortcode_atts( array(
		'post_author' => $user_id ? $user_id : 1, 
		'post_status' => 'pending',
		'post_type'   => reset( $post_types ),
	), $atts, 'cmb-shop-frontend-form' );

	foreach ( $atts as $key => $value ) {
		$cmb->add_hidden_field( array(
			'field_args'  => array(
				'id'    => 'atts[$key]',
				'type'  => 'hidden',
				'default' => $value,
			),
		) );
	}

	$output = '';

	if ( ( $error = $cmb->prop( 'submission_error' ) ) && is_wp_error( $error ) ) {
		$output .= '<span class="app-tips app-tips-error">' . sprintf( __( '提交出错: %s', '' ), '<strong>'. $error->get_error_message() .'</strong>' ) . '</span>';
	}
	$output .= cmb2_get_metabox_form( $cmb,'fake-object-id', array( 'save_button' => __( '完成提交', 'chumi' ) ) );

	return $output;
}
add_shortcode( 'cmb-shopHeader-frontend-form', 'shopHeader_frontend_form_submission_shortcode' );


function chumi_handle_frontend_new_shopHeader_form_submission() {

	if ( empty( $_POST ) || ! isset( $_POST['submit-cmb'], $_POST['object_id'] ) ) {
		return false;
	}

	$cmb = shopHeader_frontend_cmb2_get();

	$post_data = array();

	if ( isset( $_POST['atts'] ) ) {
		foreach ( (array) $_POST['atts'] as $key => $value ) {
			$post_data[ $key ] = sanitize_text_field( $value );
		}
	}

	if ( !isset( $_POST[ $cmb->nonce() ] ) || !wp_verify_nonce( $_POST[ $cmb->nonce() ], $cmb->nonce() ) ) {
		return $cmb->prop( 'submission_error', new WP_Error( 'security_fail', __( '未能通过安全检查！' ) ) );
	}	

	$sanitized_values = $cmb->get_sanitized_values( $_POST );
	
	$new_submission_id = $t;

	if ( is_wp_error( $new_submission_id ) ) {
		return $cmb->prop( 'submission_error', $new_submission_id );
	}

	unset( $post_data['post_type'] );
	unset( $post_data['post_status'] );

	foreach ( $sanitized_values as $key => $value ) {
		if ( is_array( $value ) ) {
			$value = array_filter( $value );
			if( ! empty( $value ) ) {
				update_post_meta($new_submission_id, $key, $value);
			}
		} else {
			update_post_meta($new_submission_id, $key, $value);
		}
	}
	
	wp_redirect(home_url(). '/?p='.$new_submission_id);	
	exit;	

}
add_action( 'cmb2_after_init', 'chumi_handle_frontend_new_shop_form_submission' );